"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = tslib_1.__importStar(require("react"));
var actions_1 = require("@shopify/app-bridge/actions");
var globals_1 = require("./globals");
exports.MODAL_IFRAME_NAME = 'app-modal-iframe';
var ReactShopifyAppRoutePropagator = /** @class */ (function (_super) {
    tslib_1.__extends(ReactShopifyAppRoutePropagator, _super);
    function ReactShopifyAppRoutePropagator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(ReactShopifyAppRoutePropagator.prototype, "history", {
        get: function () {
            if (!this.historyInstance) {
                var app = this.props.app;
                this.historyInstance = actions_1.History.create(app);
            }
            return this.historyInstance;
        },
        enumerable: true,
        configurable: true
    });
    ReactShopifyAppRoutePropagator.prototype.componentDidMount = function () {
        this.propagateLocation();
    };
    ReactShopifyAppRoutePropagator.prototype.componentDidUpdate = function () {
        this.propagateLocation();
    };
    ReactShopifyAppRoutePropagator.prototype.render = function () {
        return null;
    };
    ReactShopifyAppRoutePropagator.prototype.propagateLocation = function () {
        var location = this.props.location;
        var selfWindow = globals_1.getSelfWindow();
        var topWindow = globals_1.getTopWindow();
        var renderedInTheTopWindow = selfWindow === topWindow;
        var renderedInAModal = selfWindow.name === exports.MODAL_IFRAME_NAME;
        if (renderedInTheTopWindow || renderedInAModal) {
            return;
        }
        var normalizedLocation = getNormalizedURL(location);
        /*
          We delete this param that ends up unnecassarily stuck on
          the iframe due to oauth when propagating up.
        */
        normalizedLocation.searchParams.delete('hmac');
        var pathname = normalizedLocation.pathname, search = normalizedLocation.search, hash = normalizedLocation.hash;
        var locationStr = "" + pathname + search + hash;
        this.history.dispatch(actions_1.History.Action.REPLACE, locationStr);
    };
    return ReactShopifyAppRoutePropagator;
}(React.PureComponent));
exports.default = ReactShopifyAppRoutePropagator;
function getNormalizedURL(location) {
    var origin = globals_1.getOrigin();
    if (typeof location === 'string') {
        return new URL(location, origin);
    }
    var pathname = location.pathname, search = location.search, hash = location.hash;
    return new URL("" + pathname + search + hash, origin);
}
